@@ -241,13 +241,13 @@ int main( int argc, char **argv )
   int ucol, uclass;
   char ucolname[MAXCOLNAMELENGTH];
   int ucoltype;
-  int nlist;
+  int nlist = 0;
   void *listvptr[MAXLISTSIZE];
   int listvlen[MAXLISTSIZE];
 
   char item[MAXITEMLENGTH];
   char qual[MAXQUALLENGTH];
-  int quallen;
+  int quallen = 0;
 
 
   /*------ Beginning of code ------*/
