@@ -63,7 +63,6 @@ int main( int argc, char **argv )
   char *tablename=NULL;
   char *condition=NULL;
   char *outfile=NULL;
-  size_t vallen;
   int nvals;
   int valid, status, colindex;
   enum METAIO_Type coltype;
@@ -110,15 +109,12 @@ int main( int argc, char **argv )
       opt = arg[1];
       if ( strlen(arg) > 2 ) {
 	val = arg+2;
-	vallen = strlen(arg) - 2;
       } else {
 	val = NULL;
-	vallen = 0;
       }
       nvals = 0;
     } else {
       val = arg;
-      vallen = strlen(val);
       nvals++;
     }
 
