@@ -43,10 +43,12 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
+#include <zlib.h>
 
 #include "config.h"
 #include "metaio.h"
-#include "base64.h"
+#include "cdecode.h"
+#include "cencode.h"
 #include "ligo_lw_header.h"
 
 #ifdef  DEBUG
@@ -57,13 +59,6 @@
 #define DEBUGMSG2(s,d)
 #endif	/* DEBUG */
 
-#ifdef HAVE_LIBZ
-#include <zlib.h>
-
-#define gzclose(fp) gzclose((gzFile)(fp))
-#define gzgetc(fp) gzgetc((gzFile)(fp))
-#define gzungetc(c,fp) gzungetc(c,(gzFile)(fp))
-
 /*
  * Warning: This is not a fully implemented scanf routine!
  * Warning: Only a single conversion to a numeric type is supported!
@@ -155,38 +150,6 @@ static int geterrno( gzFile file, const char **msg )
     return errnum;
 }
 
-#else	/* HAVE_LIBZ */
-
-#define gzopen(path,mode) fopen(path,mode)
-#define gzclose(fp) fclose(fp)
-#define gzgetc(fp) fgetc(fp)
-#define gzungetc(c,fp) ungetc(c,fp)
-#define gzscanf fscanf
-
-static int geterrno( FILE *file, const char **msg )
-{
-    int errnum;
-    if(ferror(file))
-    {
-        /* there was an error, use errno and retrieve appropriate message */
-        *msg = strerror(errno);
-        errnum = errno;
-    }
-    else
-    {
-        /* no error */
-        *msg = NULL;
-        if(feof(file))
-            /* EOF probably doesn't overlap with any errno constants */
-            errnum = EOF;
-        else
-            errnum = 0;
-    }
-    return errnum;
-}
-
-#endif	/* HAVE_LIBZ */
-
 
 enum Token {
     CLOSE_COLUMN,
@@ -597,7 +560,7 @@ int destroy_parse_env(MetaioParseEnv const env)
     {
         if ( env->file->mode == 'r' )
         {
-            ret = gzclose(env->file->fp);
+            ret = gzclose((gzFile) env->file->fp);
             if ( ret == -3 )
                 /* XXX hack put in due to bug in zlib 1.2.2       XXX */
                 /* XXX this is not necessary in 1.2.3 and should  XXX */
@@ -671,7 +634,7 @@ int character_entity(const char* const s)
 static
 int get_char(MetaioParseEnv env)
 {
-    int c = gzgetc(env->file->fp);
+    int c = gzgetc((gzFile) env->file->fp);
 
     if(c < 0)
     {
@@ -709,7 +672,7 @@ int unget_char(MetaioParseEnv env, int c)
     if (c == '\n')
         env->file->lineno--;
 
-    return gzungetc(c, env->file->fp);
+    return gzungetc(c, (gzFile) env->file->fp);
 }
 
 /*
@@ -841,7 +804,7 @@ static int fscanf_blob(
         .len = 0,
         .datasize = 1
     };
-    int ok;
+    base64_decodestate b64state;
 
     if(!b64.data)
         /* Memory error */
@@ -868,15 +831,11 @@ static int fscanf_blob(
     }
     while(1);
 
-    /* Decode base64 data.  Formula for required length of decoded buffer
-     * copied from base64.c */
-    stringu_resize(s, 3 * (b64.len / 4) + 2);
-    ok = base64_decode(b64.data, b64.len, (char *) s->data, &s->datasize);
-    s->len = s->datasize;
+    /* Decode base64 data. */
+    stringu_resize(s, 3 * (b64.len / 4));
+    base64_init_decodestate(&b64state);
+    s->len = base64_decode_block(b64.data, b64.len, (char *) s->data, &b64state);
     free(b64.data);
-    if(!ok)
-        /* Decode error */
-        return -1;
 
     /* Done */
     return s->len;
@@ -1923,12 +1882,14 @@ int putbinary(FILE *fp, const METAIO_CHAR_U *buf, size_t len)
 static
 int putblob(FILE *fp, const METAIO_CHAR_U *buf, size_t len)
 {
-    char *b64 = NULL;
+    char *b64 = malloc(((len + 2) / 3) * 4 + 1);
+    base64_encodestate b64state;
     size_t b64len;
 
-    b64len = base64_encode_alloc((char *) buf, len, &b64);
-    if(!b64)
-        return -1;
+    base64_init_encodestate(&b64state);
+    b64len = base64_encode_block((const char *) buf, len, b64, &b64state);
+    b64len += base64_encode_blockend(b64 + b64len, &b64state);
+    b64[b64len] = 0;	/* null terminate for printing */
 
     if(fprintf(fp, "\"%s\"", b64) < 0)
     {
